pub struct Chart {
pub x_label: String,
pub x_unit: Option<String>,
pub y_label: String,
pub y_unit: Option<String>,
pub data: ChartData,
}Expand description
A declarative chart (spec 3.3): data plus axis labels only — engines describe what is charted, never colors, geometry, or layout. Every chart is table-derivable so it never gates information behind a graphics-capable format.
Fields
x_label: Stringx_unit: Option<String>y_label: Stringy_unit: Option<String>data: ChartDataTrait Implementations
Sourceimpl<'de> Deserialize<'de> for Chart
impl<'de> Deserialize<'de> for Chart
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl StructuralPartialEq for Chart